@@ -1,6 +1,6 @@
 package Shipment::UPS;
-BEGIN {
-  $Shipment::UPS::VERSION = '0.01112650';
+{
+  $Shipment::UPS::VERSION = '0.01113430';
 }
 use strict;
 use warnings;
@@ -218,7 +218,7 @@ sub _build_services {
             },
             PackageWeight => {
               UnitOfMeasurement => {
-                Code => 'LBS',
+                Code => $units_type_map{$self->weight_unit} || $self->weight_unit,
               },
               Weight => 1,
             },
@@ -245,11 +245,6 @@ sub _build_services {
           $rate = $service->get_NegotiatedRateCharges->get_TotalCharge->get_MonetaryValue;
           $currency = $service->get_NegotiatedRateCharges->get_TotalCharge->get_CurrencyCode;
         }
-        else {
-          my $notice =  "Shipper Account/UserId is not qualified to receive negotiated rates. Using published rates.";
-          warn $notice;
-          $self->add_notice( $notice . "\n" );
-        }
       }
       $services{$service->get_Service()->get_Code()->get_value} = Shipment::Service->new(
           id => $service->get_Service()->get_Code()->get_value,
@@ -398,11 +393,6 @@ sub rate {
         $rate = $response->get_RatedShipment->get_NegotiatedRateCharges->get_TotalCharge->get_MonetaryValue;
         $currency = $response->get_RatedShipment->get_NegotiatedRateCharges->get_TotalCharge->get_CurrencyCode;
       }
-      else {
-        my $notice =  "Shipper Account/UserId is not qualified to receive negotiated rates. Using published rates.";
-        warn $notice;
-        $self->add_notice( $notice . "\n" );
-      }
     }
     $self->service( 
       new Shipment::Service( 
@@ -606,11 +596,6 @@ sub ship {
         $rate = $response->get_ShipmentResults->get_NegotiatedRateCharges->get_TotalCharge->get_MonetaryValue;
         $currency = $response->get_ShipmentResults->get_NegotiatedRateCharges->get_TotalCharge->get_CurrencyCode;
       }
-      else {
-        my $notice =  "Shipper Account/UserId is not qualified to receive negotiated rates. Using published rates.";
-        warn $notice;
-        $self->add_notice( $notice . "\n" );
-      }
     }
     $self->service( 
       new Shipment::Service( 
@@ -996,7 +981,7 @@ Shipment::UPS
 
 =head1 VERSION
 
-version 0.01112650
+version 0.01113430
 
 =head1 SYNOPSIS
 
